@@ -15,6 +15,8 @@ from cubicweb import NoSelectableObject
 from cubicweb.web.views import actions, workflow, idownloadable
 
 from cubes.tracker.testutils import TrackerBaseTC
+from cubes.forge.testutils import MyValueGenerator
+
 from cubes.tracker.views import ticket, document
 from cubes.comment import views as commentactions
 from cubes.forge.views import project as myproject, boxes
@@ -22,6 +24,7 @@ from cubes.nosylist import views as nosylist
 
 ONEDAY = timedelta(1)
 
+
 class ProjectTC(TrackerBaseTC):
     """Project"""
 
@@ -31,7 +34,7 @@ class ProjectTC(TrackerBaseTC):
                               'WHERE P is Project').get_entity(0, 0)
         self.commit()
         iworkflowable = ticket.cw_adapt_to('IWorkflowable')
-        for tr, state in [('done', 'done'), 
+        for tr, state in [('done', 'done'),
                           ('ask validation', 'validation pending'),
                           ('refuse validation', 'not validated')]:
             iworkflowable.fire_transition(tr)
@@ -71,7 +74,7 @@ class ProjectTC(TrackerBaseTC):
         req = self.request()
         # manager user, in dev project
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
-        self.assertListEqual(self.pactions(req, rset),
+        self.assertUnorderedIterableEqual(self.pactions(req, rset),
                              [('workflow', workflow.WorkflowActions),
                               ('edit', actions.ModifyAction),
                               ('managepermission', actions.ManagePermissionsAction),
@@ -251,6 +254,14 @@ class ProjectTC(TrackerBaseTC):
         self.assertEqual(50, max(icon.size))
         self.assertEqual('image/png', self.cubicweb.icon_format)
 
+    def test_add_bad_icon(self):
+        """ Add an invalid icon to the project, check ValueError is raised."""
+        # add garbage
+        img = Binary("I don't exist")
+        with self.assertRaises(ValueError):
+            self.cubicweb.set_attributes(icon=img)
+        self.assertEqual(None, self.cubicweb.icon_format)
+
 
 class VersionTC(TrackerBaseTC):
     """Version"""
@@ -343,7 +354,7 @@ class TicketTC(TrackerBaseTC):
         rset = req.execute('Any X WHERE X is Ticket')
         _ticket = rset.get_entity(0, 0)
         teid = rset[0][0]
-        self.assertListEqual(self.pactions(req, rset),
+        self.assertUnorderedIterableEqual(self.pactions(req, rset),
                              [('workflow', workflow.WorkflowActions),
                               ('edit', actions.ModifyAction),
                               ('managepermission', actions.ManagePermissionsAction),
